# <img src='./res/logo.png' width='50' height='50' style='vertical-align:bottom'/> BandCamp Skill

## About

Bandcamp skill for your hipster music needs

![](./gui.gif)

## Examples
* "play compressorhead"
* "play astronaut problems"
* "play {artist/album/genre/track}"

* "search bandcamp for black metal"
* "search bandcamp for {artist/album/genre/track}"

* "play center of all infinity album"
* "play {album} album"

* "play freezing moon by mayhem"
* "play {track} by {artist}"


## Credits
JarbasAl

## Category
**Entertainment**

## Tags
- music
- audio
- bandcamp
- common play

